package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.CallMeta;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.HYKArtifact;

import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.artifacts.model.HYKFacet;
import de.intevation.flys.artifacts.model.HYKFactory;

import de.intevation.flys.utils.FLYSUtils;


/**
 * Only state of a HYKArtifact.
 */
public class StaticHYKState
extends      DefaultState
implements   FacetTypes
{
    /** The logger that is used in this state. */
    transient private static final Logger logger = Logger.getLogger(StaticHYKState.class);


    /**
     * From this state can not be continued.
     */
    @Override
    protected String getUIProvider() {
        return "noinput";
    }


    /**
     * Compute, create Facets, do the same stuff as all the other states do.
     */
    protected Object compute(
        HYKArtifact   hyk,
        CallMeta      metaLocale,
        String        hash,
        List<Facet>   facets,
        Object        old
    ) {
        logger.debug("StaticHYKState.compute");
        String id = getID();

        // TODO caching!

        /*
        WQKms res = old instanceof WQKms
            ? (WQKms)old
            : winfo.getWQKms();

        WQKms wqkms = res;
        */

        // List<Zone> res;
        Object res = null;

        // Compare against cached objects.

        // Need river id and km.
        List<HYKFactory.Zone> zones = (List<HYKFactory.Zone>)
            HYKFactory.getHYKs(hyk.getHykId(), hyk.getKm());

        if (facets == null) {
            logger.debug("StaticHYKState.compute no facets");
            return zones;
        }

        Facet facet = new HYKFacet(0, HYKFactory.getHykName(hyk.getHykId()));

        facets.add(facet);

        return zones;
    }


    /**
     * Get data, create the facets.
     *
     * @param context Ignored.
     */
    @Override
    public Object computeFeed(
        FLYSArtifact artifact,
        String       hash,
        CallContext  context,
        List<Facet>  facets,
        Object       old
    ) {
        return compute((HYKArtifact) artifact, context.getMeta(),
            hash, facets, old);
    }


    /**
     * Create the facets.
     * @param context Ignored.
     */
    @Override
    public Object computeInit(
        FLYSArtifact artifact,
        String       hash,
        Object       context,
        CallMeta     meta,
        List<Facet>  facets
    ) {
        return compute((HYKArtifact) artifact, meta, hash, facets,
            null);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
